@@ -1,4 +1,5 @@
 """Exception handling module"""
+
 from gettext import gettext as _
 
 
@@ -19,7 +20,7 @@ class MisconfigurationError(LutrisError):
 class DirectoryNotFoundError(MisconfigurationError):
     """Raise this error if a directory that is required is not present."""
 
-    def __init__(self, *args, message=None, directory=None, **kwarg):
+    def __init__(self, message=None, directory=None, *args, **kwarg):
         if not message and directory:
             message = _("The directory {} could not be found").format(directory)
         super().__init__(message, *args, **kwarg)
@@ -34,7 +35,7 @@ class GameConfigError(MisconfigurationError):
 class MissingBiosError(GameConfigError):
     """Throw this error when the game requires a BIOS, but none is configured."""
 
-    def __init__(self, *args, message=None, **kwarg):
+    def __init__(self, message=None, *args, **kwarg):
         super().__init__(message or _("A bios file is required to run this game"), *args, **kwarg)
 
 
@@ -48,11 +49,8 @@ class UnavailableGameError(LutrisError):
 
 class UnavailableLibrariesError(MisconfigurationError):
     def __init__(self, libraries, arch=None):
-        message = _(
-            "The following {arch} libraries are required but are not installed on your system:\n{libs}"
-        ).format(
-            arch=arch if arch else "",
-            libs=", ".join(libraries)
+        message = _("The following {arch} libraries are required but are not installed on your system:\n{libs}").format(
+            arch=arch if arch else "", libs=", ".join(libraries)
         )
         super().__init__(message)
         self.libraries = libraries
@@ -73,7 +71,7 @@ class MissingExecutableError(MisconfigurationError):
 class MissingMediaError(LutrisError):
     """Raised when an image file could not be found."""
 
-    def __init__(self, *args, message=None, filename=None, **kwargs):
+    def __init__(self, message=None, filename=None, *args, **kwargs):
         if not message and filename:
             message = _("The file {} could not be found").format(filename)
 
@@ -84,7 +82,7 @@ class MissingMediaError(LutrisError):
 class MissingGameExecutableError(MissingExecutableError):
     """Raise when a game's executable can't be found is not specified."""
 
-    def __init__(self, *args, message=None, filename=None, **kwargs):
+    def __init__(self, message=None, filename=None, *args, **kwargs):
         if not message:
             if filename:
                 message = _("The file {} could not be found").format(filename)
@@ -102,6 +100,18 @@ class InvalidGameMoveError(LutrisError):
 class EsyncLimitError(Exception):
     """Raised when the ESYNC limit is not set correctly."""
 
+    def __init__(self, message=None, *args, **kwarg):
+        if not message:
+            message = _("Your ESYNC limits are not set correctly.")
+
+        super().__init__(message, *args, **kwarg)
+
 
 class FsyncUnsupportedError(Exception):
     """Raised when FSYNC is enabled, but is not supported by the kernel."""
+
+    def __init__(self, message=None, *args, **kwarg):
+        if not message:
+            message = _("Your kernel is not patched for fsync." " Please get a patched kernel to use fsync.")
+
+        super().__init__(message, *args, **kwarg)
