@@ -1,12 +1,14 @@
 """Commonly used dialogs"""
+
 import os
+import traceback
 from gettext import gettext as _
-from typing import Callable
+from typing import Callable, Union
 
 import gi
 
-gi.require_version('Gdk', '3.0')
-gi.require_version('Gtk', '3.0')
+gi.require_version("Gdk", "3.0")
+gi.require_version("Gtk", "3.0")
 
 from gi.repository import Gdk, GLib, GObject, Gtk
 
@@ -25,9 +27,14 @@ class Dialog(Gtk.Dialog):
     the response for you via 'response_type' or 'confirmed' and destory this
     dialog if it isn't NONE."""
 
-    def __init__(self, title: str = None, parent: Gtk.Widget = None,
-                 flags: Gtk.DialogFlags = 0, buttons: Gtk.ButtonsType = None,
-                 **kwargs):
+    def __init__(
+        self,
+        title: str = None,
+        parent: Gtk.Widget = None,
+        flags: Gtk.DialogFlags = 0,
+        buttons: Gtk.ButtonsType = None,
+        **kwargs,
+    ):
         super().__init__(title, parent, flags, buttons, **kwargs)
         self._response_type = Gtk.ResponseType.NONE
         self.connect("response", self.on_response)
@@ -74,16 +81,14 @@ class Dialog(Gtk.Dialog):
         idle_source_id = GLib.idle_add(idle_destroy)
         on_destroy_id = self.connect("destroy", on_destroy)
 
-    def add_styled_button(self, button_text: str, response_id: Gtk.ResponseType,
-                          css_class: str):
+    def add_styled_button(self, button_text: str, response_id: Gtk.ResponseType, css_class: str):
         button = self.add_button(button_text, response_id)
         if css_class:
             style_context = button.get_style_context()
             style_context.add_class(css_class)
         return button
 
-    def add_default_button(self, button_text: str, response_id: Gtk.ResponseType,
-                           css_class: str = "suggested-action"):
+    def add_default_button(self, button_text: str, response_id: Gtk.ResponseType, css_class: str = "suggested-action"):
         """Adds a button to the dialog with a particular response id, but
         also makes it the default and styles it as the suggested action."""
         button = self.add_styled_button(button_text, response_id, css_class)
@@ -97,9 +102,14 @@ class ModalDialog(Dialog):
     Unlike plain Gtk.Dialog, these destroy themselves (at idle-time) after
     you call run(), even if you forget to. They aren't meant to be reused."""
 
-    def __init__(self, title: str = None, parent: Gtk.Widget = None,
-                 flags: Gtk.DialogFlags = 0, buttons: Gtk.ButtonsType = None,
-                 **kwargs):
+    def __init__(
+        self,
+        title: str = None,
+        parent: Gtk.Widget = None,
+        flags: Gtk.DialogFlags = 0,
+        buttons: Gtk.ButtonsType = None,
+        **kwargs,
+    ):
         super().__init__(title, parent, flags | Gtk.DialogFlags.MODAL, buttons, **kwargs)
         self.set_destroy_with_parent(True)
 
@@ -119,9 +129,14 @@ class ModelessDialog(Dialog):
     its own window group, so it treats its own modal dialogs separately, and it resets
     its transient-for after being created."""
 
-    def __init__(self, title: str = None, parent: Gtk.Widget = None,
-                 flags: Gtk.DialogFlags = 0, buttons: Gtk.ButtonsType = None,
-                 **kwargs):
+    def __init__(
+        self,
+        title: str = None,
+        parent: Gtk.Widget = None,
+        flags: Gtk.DialogFlags = 0,
+        buttons: Gtk.ButtonsType = None,
+        **kwargs,
+    ):
         super().__init__(title, parent, flags, buttons, **kwargs)
         # These are not stuck above the 'main' window, but can be
         # re-ordered freely.
@@ -227,9 +242,9 @@ class AboutDialog(GtkBuilderDialog):
 class NoticeDialog(Gtk.MessageDialog):
     """Display a message to the user."""
 
-    def __init__(self, message, secondary=None, parent=None):
+    def __init__(self, message_markup: str, secondary: str = None, parent: Gtk.Window = None):
         super().__init__(message_type=Gtk.MessageType.INFO, buttons=Gtk.ButtonsType.OK, parent=parent)
-        self.set_markup(message)
+        self.set_markup(message_markup)
         if secondary:
             self.format_secondary_text(secondary[:256])
 
@@ -246,9 +261,9 @@ class WarningDialog(Gtk.MessageDialog):
     """Display a warning to the user, who responds with whether to proceed, like
     a QuestionDialog."""
 
-    def __init__(self, message, secondary=None, parent=None):
+    def __init__(self, message_markup: str, secondary: str = None, parent: Gtk.Window = None):
         super().__init__(message_type=Gtk.MessageType.WARNING, buttons=Gtk.ButtonsType.OK_CANCEL, parent=parent)
-        self.set_markup(message)
+        self.set_markup(message_markup)
         if secondary:
             self.format_secondary_text(secondary[:256])
 
@@ -264,17 +279,30 @@ class WarningDialog(Gtk.MessageDialog):
 class ErrorDialog(Gtk.MessageDialog):
     """Display an error message."""
 
-    def __init__(self, error, secondary=None, parent=None):
-        super().__init__(buttons=Gtk.ButtonsType.OK, parent=parent)
+    def __init__(
+        self,
+        error: Union[str, BaseException],
+        message_markup: str = None,
+        secondary: str = None,
+        parent: Gtk.Window = None,
+    ):
+        super().__init__(message_type=Gtk.MessageType.ERROR, buttons=Gtk.ButtonsType.OK, parent=parent)
 
-        # Some errors contain < and > and lok like markup, but aren't-
-        # we'll need to protect the message box against this
-        message = gtk_safe(error) if isinstance(error, BaseException) else str(error)
+        if isinstance(error, BaseException):
+            if secondary:
+                # Some errors contain < and > and look like markup, but aren't-
+                # we'll need to protect the message dialog against this. To use markup,
+                # you must pass the message itself directly.
+                message_markup = message_markup or gtk_safe(str(error))
+            elif not message_markup:
+                message_markup = "<span weight='bold'>%s</span>" % _("Lutris has encountered an error")
+                secondary = str(error)
+        elif not message_markup:
+            message_markup = gtk_safe(str(error))
 
         # Gtk doesn't wrap long labels containing no space correctly
         # the length of the message is limited to avoid display issues
-
-        self.set_markup(message[:256])
+        self.set_markup(message_markup[:256])
 
         if secondary:
             self.format_secondary_text(secondary[:256])
@@ -284,9 +312,54 @@ class ErrorDialog(Gtk.MessageDialog):
             if isinstance(child, Gtk.Label):
                 child.set_selectable(True)
 
+        if isinstance(error, BaseException):
+            content_area = self.get_content_area()
+            spacing = content_area.get_spacing()
+            content_area.set_spacing(0)
+
+            details_expander = self.get_details_expander(error)
+            details_expander.set_margin_top(spacing)
+            content_area.pack_end(details_expander, False, False, 0)
+
+            action_area = self.get_action_area()
+            copy_button = Gtk.Button(_("Copy to Clipboard"), visible=True)
+            action_area.pack_start(copy_button, False, True, 0)
+            action_area.set_child_secondary(copy_button, True)
+            copy_button.connect("clicked", self.on_copy_clicked, error)
+
         self.run()
         self.destroy()
 
+    def on_copy_clicked(self, _button, error: BaseException):
+        details = self.format_error(error)
+        clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
+        clipboard.set_text(details, -1)
+
+    def get_details_expander(self, error: BaseException) -> Gtk.Widget:
+        details = self.format_error(error, include_message=False)
+        expander = Gtk.Expander.new(_("Error details"))
+
+        details_box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+
+        details_box.pack_start(Gtk.Separator(margin_top=6), False, False, 0)
+
+        details_textview = Gtk.TextView(editable=False)
+        details_textview.get_buffer().set_text(details)
+
+        details_scrolledwindow = Gtk.ScrolledWindow(width_request=800, height_request=400)
+        details_scrolledwindow.add(details_textview)
+        details_box.pack_start(details_scrolledwindow, False, False, 0)
+        expander.add(details_box)
+        expander.show_all()
+        return expander
+
+    @staticmethod
+    def format_error(error: BaseException, include_message: bool = True):
+        formatted = traceback.format_exception(type(error), error, error.__traceback__)
+        if include_message:
+            formatted = [str(error), ""] + formatted
+        return "\n".join(formatted).strip()
+
 
 class QuestionDialog(Gtk.MessageDialog):
     """Ask the user a yes or no question."""
@@ -381,7 +454,6 @@ class FileDialog:
 
 
 class InstallOrPlayDialog(ModalDialog):
-
     def __init__(self, game_name, parent=None):
         super().__init__(title=_("%s is already installed") % game_name, parent=parent, border_width=10)
         self.action = "play"
@@ -564,9 +636,11 @@ class MoveDialog(ModelessDialog):
 
     def _move_game_cb(self, _result, error):
         if error and isinstance(error, InvalidGameMoveError):
-            secondary = _("Do you want to change the game location anyway? No files can be moved, "
-                          "and the game configuration may need to be adjusted.")
-            dlg = WarningDialog(str(error), secondary=secondary, parent=self)
+            secondary = _(
+                "Do you want to change the game location anyway? No files can be moved, "
+                "and the game configuration may need to be adjusted."
+            )
+            dlg = WarningDialog(message_markup=error, secondary=secondary, parent=self)
             if dlg.result == Gtk.ResponseType.OK:
                 self.new_directory = self.game.set_location(self.destination)
                 self.on_game_moved(None, None)
@@ -596,22 +670,24 @@ class HumbleBundleCookiesDialog(ModalDialog):
         vbox = Gtk.Box.new(Gtk.Orientation.VERTICAL, 6)
         self.get_content_area().add(vbox)
         label = Gtk.Label()
-        label.set_markup(_(
-            "<b>Humble Bundle Authentication via cookie import</b>\n"
-            "\n"
-            "<b>In Firefox</b>\n"
-            "- Install the following extension: "
-            "<a href='https://addons.mozilla.org/en-US/firefox/addon/export-cookies-txt/'>"
-            "https://addons.mozilla.org/en-US/firefox/addon/export-cookies-txt/"
-            "</a>\n"
-            "- Open a tab to humblebundle.com and make sure you are logged in.\n"
-            "- Click the cookie icon in the top right corner, next to the settings menu\n"
-            "- Check 'Prefix HttpOnly cookies' and click 'humblebundle.com'\n"
-            "- Open the generated file and paste the contents below. Click OK to finish.\n"
-            "- You can delete the cookies file generated by Firefox\n"
-            "- Optionally, <a href='https://support.humblebundle.com/hc/en-us/requests/new'>"
-            "open a support ticket</a> to ask Humble Bundle to fix their configuration."
-        ))
+        label.set_markup(
+            _(
+                "<b>Humble Bundle Authentication via cookie import</b>\n"
+                "\n"
+                "<b>In Firefox</b>\n"
+                "- Install the following extension: "
+                "<a href='https://addons.mozilla.org/en-US/firefox/addon/export-cookies-txt/'>"
+                "https://addons.mozilla.org/en-US/firefox/addon/export-cookies-txt/"
+                "</a>\n"
+                "- Open a tab to humblebundle.com and make sure you are logged in.\n"
+                "- Click the cookie icon in the top right corner, next to the settings menu\n"
+                "- Check 'Prefix HttpOnly cookies' and click 'humblebundle.com'\n"
+                "- Open the generated file and paste the contents below. Click OK to finish.\n"
+                "- You can delete the cookies file generated by Firefox\n"
+                "- Optionally, <a href='https://support.humblebundle.com/hc/en-us/requests/new'>"
+                "open a support ticket</a> to ask Humble Bundle to fix their configuration."
+            )
+        )
         vbox.pack_start(label, False, False, 24)
         self.textview = Gtk.TextView()
         self.textview.set_left_margin(12)
