@@ -17,30 +17,22 @@ class DownloadDialog(ModalDialog):
 
         self.dialog_progress_box.connect("complete", self.download_complete)
         self.dialog_progress_box.connect("cancel", self.download_cancelled)
-        self.connect("response", self.on_response)
 
         self.get_content_area().add(self.dialog_progress_box)
         self.show_all()
         self.dialog_progress_box.start()
 
+    @property
+    def downloader(self):
+        return self.dialog_progress_box.downloader
+
     def download_complete(self, _widget, _data):
         self.response(Gtk.ResponseType.OK)
-        self.destroy()
 
     def download_cancelled(self, _widget):
         self.response(Gtk.ResponseType.CANCEL)
-        self.destroy()
 
-    def on_response(self, _dialog, response):
-        if response == Gtk.ResponseType.DELETE_EVENT:
+    def on_response(self, dialog, response):
+        if response in (Gtk.ResponseType.DELETE_EVENT, Gtk.ResponseType.CANCEL):
             self.dialog_progress_box.downloader.cancel()
-            self.destroy()
-
-
-def simple_downloader(url, destination, callback, callback_args=None):
-    """Basic downloader with a DownloadDialog"""
-    if not callback_args:
-        callback_args = {}
-    dialog = DownloadDialog(url, destination)
-    dialog.run()
-    return callback(**callback_args)
+        super().on_response(dialog, response)
