@@ -1,3 +1,4 @@
+# pylint: disable=no-member
 # pylint:disable=using-constant-test
 # pylint:disable=comparison-with-callable
 from gettext import gettext as _
@@ -5,16 +6,20 @@ from math import floor
 
 import gi
 
-gi.require_version('PangoCairo', '1.0')
+gi.require_version("PangoCairo", "1.0")
 
 import cairo
-from gi.repository import GLib, GObject, Gtk, Pango, PangoCairo
+from gi.repository import Gdk, GLib, GObject, Gtk, Pango, PangoCairo
 
-from lutris.exceptions import MissingMediaError
 from lutris.gui.widgets.utils import (
-    MEDIA_CACHE_INVALIDATED, get_default_icon_path, get_runtime_icon_path, get_scaled_surface_by_path, get_surface_size
+    MEDIA_CACHE_INVALIDATED,
+    get_default_icon_path,
+    get_runtime_icon_path,
+    get_scaled_surface_by_path,
+    get_surface_size,
 )
-from lutris.scanners.lutris import is_game_missing
+from lutris.services.service_media import resolve_media_path
+from lutris.util.path_cache import MISSING_GAMES
 
 
 class GridViewCellRendererText(Gtk.CellRendererText):
@@ -99,7 +104,8 @@ class GridViewCellRendererImage(Gtk.CellRenderer):
         self._media_width = 0
         self._media_height = 0
         self._game_id = None
-        self._media_path = None
+        self._service = None
+        self._media_paths = []
         self._show_badges = True
         self._platform = None
         self._is_installed = True
@@ -167,14 +173,22 @@ class GridViewCellRendererImage(Gtk.CellRenderer):
     def game_id(self, value):
         self._game_id = value
 
-    @GObject.Property(type=str)
-    def media_path(self):
-        """This is the path to the media file to be displayed."""
-        return self._media_path
+    @GObject.Property(type=GObject.TYPE_PYOBJECT)
+    def service(self):
+        return self._service
 
-    @media_path.setter
-    def media_path(self, value):
-        self._media_path = value
+    @service.setter
+    def service(self, value):
+        self._service = value
+
+    @GObject.Property(type=GObject.TYPE_PYOBJECT)
+    def media_paths(self):
+        """This is the list of paths where the media to be displayed may be."""
+        return self._media_paths
+
+    @media_paths.setter
+    def media_paths(self, value):
+        self._media_paths = value
 
     @GObject.Property(type=bool, default=True)
     def show_badges(self):
@@ -214,7 +228,7 @@ class GridViewCellRendererImage(Gtk.CellRenderer):
     def do_render(self, cr, widget, background_area, cell_area, flags):
         media_width = self.media_width
         media_height = self.media_height
-        path = self.media_path
+        path = resolve_media_path(self.media_paths) if self.media_paths else None
         alpha = 1 if self.is_installed else 100 / 255
 
         if media_width > 0 and media_height > 0 and path:
@@ -222,39 +236,35 @@ class GridViewCellRendererImage(Gtk.CellRenderer):
             if not surface:
                 # The default icon needs to be scaled to fill the cell space.
                 path = get_default_icon_path((media_width, media_height))
-                surface = self._get_cached_surface_by_path(widget, path,
-                                                           preserve_aspect_ratio=False)
+                surface = self._get_cached_surface_by_path(widget, path, preserve_aspect_ratio=False)
             if surface:
-                x, y = self.get_media_position(surface, cell_area)
+                media_area = self.get_media_area(surface, cell_area)
                 self.select_badge_metrics(surface)
 
                 cr.save()
+
+                # Adjust context to place media_area at 0,0 and scale it.
                 inset_fraction = self._inset_fractions.get(self.game_id) or 0.0 if self.game_id else 0.0
                 if inset_fraction > 0:
-                    x += (cell_area.width * inset_fraction) / 2
-                    y += (cell_area.height * inset_fraction) / 2
-                    cell_area.y = 0
-                    cell_area.x = 0
-
-                    cr.translate(x, y)
+                    media_area.x += (media_area.width * inset_fraction) / 2
+                    media_area.y += (media_area.height * inset_fraction) / 2
+                    cr.translate(media_area.x, media_area.y)
                     cr.scale(1 - inset_fraction, 1 - inset_fraction)
                 else:
-                    cell_area.y = 0
-                    cell_area.x = 0
-                    cr.translate(x, y)
+                    cr.translate(media_area.x, media_area.y)
+
+                media_area.x = 0
+                media_area.y = 0
 
                 if alpha >= 1:
                     self.render_media(cr, widget, surface, 0, 0)
                     if self.show_badges:
-                        self.render_platforms(cr, widget, surface, 0, cell_area)
-
-                        if self.game_id and is_game_missing(self.game_id):
-                            self.render_text_badge(cr, widget, _("Missing"), 0, cell_area.y + cell_area.height)
+                        self._render_badges(cr, widget, surface, media_area)
                 else:
                     cr.push_group()
                     self.render_media(cr, widget, surface, 0, 0)
                     if self.show_badges:
-                        self.render_platforms(cr, widget, surface, 0, cell_area)
+                        self._render_badges(cr, widget, surface, media_area)
                     cr.pop_group_to_source()
                     cr.paint_with_alpha(alpha)
                 cr.restore()
@@ -317,7 +327,7 @@ class GridViewCellRendererImage(Gtk.CellRenderer):
                 data = surface.get_data()
 
                 offset = (y * stride) + x * 4
-                pixel = data[offset: offset + 4]
+                pixel = data[offset : offset + 4]
 
                 for channel in pixel:
                     if channel < 128:
@@ -332,13 +342,16 @@ class GridViewCellRendererImage(Gtk.CellRenderer):
             and is_bright_pixel(pixel_width - corner_pixel_width, pixel_height - corner_pixel_height)
         )
 
-    def get_media_position(self, surface, cell_area):
+    @staticmethod
+    def get_media_area(surface, cell_area):
         """Computes the position of the upper left corner where we will render
         a surface within the cell area."""
+        media_area = Gdk.Rectangle()
         width, height = get_surface_size(surface)
-        x = round(cell_area.x + (cell_area.width - width) / 2)  # centered
-        y = round(cell_area.y + cell_area.height - height)  # at bottom of cell
-        return x, y
+        media_area.x = round(cell_area.x + (cell_area.width - width) / 2)  # centered
+        media_area.y = round(cell_area.y + cell_area.height - height)  # at bottom of cell
+        media_area.width, media_area.height = width, height
+        return media_area
 
     def render_media(self, cr, widget, surface, x, y):
         """Renders the media itself, given the surface containing it
@@ -350,14 +363,24 @@ class GridViewCellRendererImage(Gtk.CellRenderer):
         cr.rectangle(x, y, width, height)
         cr.fill()
 
-    def render_platforms(self, cr, widget, surface, surface_x, cell_area):
-        """Renders the stack of platform icons. They appear lined up vertically to the
-        right of 'media_right', if that will fit in 'cell_area'."""
+    def _render_badges(self, cr, widget, surface, media_area):
+        self.render_platforms(cr, widget, surface, 0, media_area)
+
+        game_id = self.game_id
+        if game_id:
+            if self.service:
+                game_id = self.service.resolve_game_id(game_id)
+
+            if game_id in MISSING_GAMES.missing_game_ids:
+                self.render_text_badge(cr, widget, _("Missing"), 0, media_area.y + media_area.height)
+
+    def render_platforms(self, cr, widget, surface, surface_x, media_area):
+        """Renders the stack of platform icons."""
         platform = self.platform
         if platform and self.badge_size:
             icon_paths = self.get_platform_icon_paths(platform)
             if icon_paths:
-                self.render_badge_stack(cr, widget, surface, surface_x, icon_paths, cell_area)
+                self.render_badge_stack(cr, widget, surface, surface_x, icon_paths, media_area)
 
     @staticmethod
     def get_platform_icon_paths(platform):
@@ -371,20 +394,19 @@ class GridViewCellRendererImage(Gtk.CellRenderer):
 
         icon_paths = []
         for p in platforms:
-            try:
-                icon_paths.append(get_runtime_icon_path(p + "-symbolic"))
-            except MissingMediaError:
-                continue  # just leave the missing icons out
+            icon_path = get_runtime_icon_path(p + "-symbolic")
+            if icon_path:
+                icon_paths.append(icon_path)
 
         GridViewCellRendererImage._platform_icon_paths[platform] = icon_paths
         return icon_paths
 
     _platform_icon_paths = {}
 
-    def render_badge_stack(self, cr, widget, surface, surface_x, icon_paths, cell_area):
-        """Renders a vertical stack of badges, placed at the edge of the media, off to the right
-        of 'media_right' if this will fit in the 'cell_area'. The icons in icon_paths are drawn from
-        top to bottom, and spaced to fit in 'cell_area', even if they overlap because of this."""
+    def render_badge_stack(self, cr, widget, surface, surface_x, icon_paths, media_area):
+        """Renders a vertical stack of badges, placed at the edge of the media, just to the left
+        of 'media_area.right'. The icons in icon_paths are drawn from top to bottom, and spaced
+        to fit in 'media_area', even if they overlap because of this."""
 
         badge_width = self.badge_size[0]
         badge_height = self.badge_size[1]
@@ -404,10 +426,10 @@ class GridViewCellRendererImage(Gtk.CellRenderer):
         media_right = surface_x + get_surface_size(surface)[0]
 
         x = media_right - badge_width
-        spacing = (cell_area.height - badge_height * len(icon_paths)) / max(1, len(icon_paths) - 1)
+        spacing = (media_area.height - badge_height * len(icon_paths)) / max(1, len(icon_paths) - 1)
         spacing = min(spacing, 1)
         y_offset = floor(badge_height + spacing)
-        y = cell_area.y + cell_area.height - badge_height - y_offset * (len(icon_paths) - 1)
+        y = media_area.y + media_area.height - badge_height - y_offset * (len(icon_paths) - 1)
 
         for icon_path in icon_paths:
             render_badge(x, y, icon_path)
@@ -500,13 +522,11 @@ class GridViewCellRendererImage(Gtk.CellRenderer):
         if key in self.cached_surfaces_old:
             surface = self.cached_surfaces_old[key]
         else:
-            try:
-                surface = self._get_surface_by_path(widget, path, size, preserve_aspect_ratio)
+            surface = self._get_surface_by_path(widget, path, size, preserve_aspect_ratio)
+            if surface:
                 # We cache missing surfaces too, but only a successful load trigger
                 # cache cycling
                 self.cached_surfaces_loaded += 1
-            except MissingMediaError:
-                surface = None
 
         self.cached_surfaces_new[key] = surface
         return surface
@@ -514,5 +534,4 @@ class GridViewCellRendererImage(Gtk.CellRenderer):
     def _get_surface_by_path(self, widget, path, size=None, preserve_aspect_ratio=True):
         cell_size = size or (self.media_width, self.media_height)
         scale_factor = widget.get_scale_factor() if widget else 1
-        return get_scaled_surface_by_path(path, cell_size, scale_factor,
-                                          preserve_aspect_ratio=preserve_aspect_ratio)
+        return get_scaled_surface_by_path(path, cell_size, scale_factor, preserve_aspect_ratio=preserve_aspect_ratio)
