@@ -1,4 +1,5 @@
 """Various utilities using the GObject framework"""
+
 import array
 import os
 
@@ -38,21 +39,21 @@ def open_uri(uri):
     system.spawn(["xdg-open", uri])
 
 
-def get_image_file_format(path):
-    """Returns the file format fo an image, either 'jpeg' or 'png';
-    we deduce this from the file extension, or if that fails the
+def get_image_file_extension(path):
+    """Returns the canonical file extension for an image,
+    either 'jpg' or 'png'; we deduce this from the file extension, or if that fails the
     file's 'magic' prefix bytes."""
-    ext = os.path.splitext(path)[1].lower()
+    ext = os.path.splitext(path)[1].casefold()
     if ext in [".jpg", ".jpeg"]:
-        return "jpeg"
+        return ".jpg"
     if path == ".png":
-        return "png"
+        return ".png"
 
-    file_type = magic.from_file(path).lower()
+    file_type = magic.from_file(path).casefold()
     if "jpeg image data" in file_type:
-        return "jpeg"
+        return ".jpg"
     if "png image data" in file_type:
-        return "png"
+        return ".png"
 
     return None
 
@@ -76,9 +77,12 @@ def get_scaled_surface_by_path(path, size, device_scale, preserve_aspect_ratio=T
     If you pass True for preserve_aspect_ratio, the aspect ratio of the image is preserved,
     but will be no larger than the size (times the device_scale).
 
-    If the path cannot be read, this returns None.
+    If there's no file at the path, or it is empty, this function returns None.
     """
     pixbuf = get_pixbuf_by_path(path)
+    if not pixbuf:
+        return None
+
     pixbuf_width = pixbuf.get_width()
     pixbuf_height = pixbuf.get_height()
 
@@ -115,21 +119,32 @@ def get_default_icon_path(size):
 def get_pixbuf_by_path(path, size=None, preserve_aspect_ratio=True):
     """Reads an image file and returns the pixbuf. If you provide a size, this scales
     the file to fit that size, preserving the aspect ratio if preserve_aspect_ratio is
-    True. If the file is missing or unreadable, or if 'path' is None, this raises
-    MissingMediaError."""
+    True. If the file is missing or empty, or if 'path' is None or empty,
+    this returns None. Still raises GLib.GError for corrupt files."""
     if not system.path_exists(path, exclude_empty=True):
-        raise MissingMediaError(filename=path)
+        return None
 
+    if size:
+        # new_from_file_at_size scales but preserves aspect ratio
+        width, height = size
+        if preserve_aspect_ratio:
+            return GdkPixbuf.Pixbuf.new_from_file_at_size(path, width, height)
+
+        return GdkPixbuf.Pixbuf.new_from_file_at_scale(path, width, height, preserve_aspect_ratio=False)
+
+    return GdkPixbuf.Pixbuf.new_from_file(path)
+
+
+def get_required_pixbuf_by_path(path, size=None, preserve_aspect_ratio=True):
+    """Reads an image file and returns the pixbuf. If you provide a size, this scales
+    the file to fit that size, preserving the aspect ratio if preserve_aspect_ratio is
+    True. If the file is missing or unreadable, or if 'path' is None or empty, this raises
+    MissingMediaError."""
     try:
-        if size:
-            # new_from_file_at_size scales but preserves aspect ratio
-            width, height = size
-            if preserve_aspect_ratio:
-                return GdkPixbuf.Pixbuf.new_from_file_at_size(path, width, height)
-
-            return GdkPixbuf.Pixbuf.new_from_file_at_scale(path, width, height, preserve_aspect_ratio=False)
-
-        return GdkPixbuf.Pixbuf.new_from_file(path)
+        pixbuf = get_pixbuf_by_path(path, size, preserve_aspect_ratio)
+        if not pixbuf:
+            raise MissingMediaError(filename=path)
+        return pixbuf
     except GLib.GError as ex:
         logger.exception("Unable to load icon from image %s", path)
         raise MissingMediaError(message=str(ex), filename=path) from ex
@@ -153,7 +168,7 @@ def get_runtime_icon_path(icon_name):
     icon_name -- The name of the icon to retrieve
 
     Returns:
-        The path to the icon, or raises MissingMediaError if it wasn't found.
+        The path to the icon, or None if it wasn't found.
     """
     filename = icon_name.lower().replace(" ", "")
     # We prefer bitmaps over SVG, because we've got some SVG icons with the
@@ -163,14 +178,15 @@ def get_runtime_icon_path(icon_name):
         "icons/hicolor/24x24/apps",
         "icons",
         "icons/hicolor/scalable/apps",
-        "icons/hicolor/symbolic/apps"]
+        "icons/hicolor/symbolic/apps",
+    ]
     extensions = [".png", ".svg"]
     for search_dir in search_directories:
         for ext in extensions:
             icon_path = os.path.join(settings.RUNTIME_DIR, search_dir, filename + ext)
             if os.path.exists(icon_path):
                 return icon_path
-    raise MissingMediaError("The icon '%s' could not be found." % icon_name)
+    return None
 
 
 def convert_to_background(background_path, target_size=(320, 1080)):
@@ -189,7 +205,7 @@ def convert_to_background(background_path, target_size=(320, 1080)):
     coverart = coverart.crop((offset, 0, target_width + offset, image_height))
 
     # Resize canvas of coverart by putting transparent pixels on the bottom
-    coverart_bg = Image.new('RGBA', (target_width, target_height), (0, 0, 0, 0))
+    coverart_bg = Image.new("RGBA", (target_width, target_height), (0, 0, 0, 0))
     coverart_bg.paste(coverart, (0, 0, target_width, image_height))
 
     # Apply a tint to the base image
@@ -197,7 +213,7 @@ def convert_to_background(background_path, target_size=(320, 1080)):
     # coverart = Image.blend(coverart, tint, 0.6)
 
     # Paste coverart on transparent image while applying a gradient mask
-    background = Image.new('RGBA', (target_width, target_height), (0, 0, 0, 0))
+    background = Image.new("RGBA", (target_width, target_height), (0, 0, 0, 0))
     mask = Image.open(os.path.join(datapath.get(), "media/mask.png"))
     background.paste(coverart_bg, mask=mask)
 
@@ -230,20 +246,14 @@ def paste_overlay(base_image, overlay_image, position=0.7):
     offset_x = int((base_width - overlay_width) / 2)
     offset_y = int((base_height - overlay_height) / 2)
     base_image.paste(
-        overlay_image, (
-            offset_x,
-            offset_y,
-            overlay_width + offset_x,
-            overlay_height + offset_y
-        ),
-        mask=overlay_image
+        overlay_image, (offset_x, offset_y, overlay_width + offset_x, overlay_height + offset_y), mask=overlay_image
     )
     return base_image
 
 
 def image2pixbuf(image):
     """Converts a PIL Image to a GDK Pixbuf"""
-    image_array = array.array('B', image.tobytes())
+    image_array = array.array("B", image.tobytes())
     width, height = image.size
     return GdkPixbuf.Pixbuf.new_from_data(image_array, GdkPixbuf.Colorspace.RGB, True, 8, width, height, width * 4)
 
