@@ -3,17 +3,14 @@ from gi.repository import Gtk
 
 
 class BaseApplicationWindow(Gtk.ApplicationWindow):
-
     """Window used to guide the user through a issue reporting process"""
 
     def __init__(self, application):
         Gtk.ApplicationWindow.__init__(self, icon_name="lutris", application=application)
         self.application = application
         self.set_show_menubar(False)
-        self.set_size_request(420, 420)
-        self.set_default_size(600, 480)
+
         self.set_position(Gtk.WindowPosition.CENTER)
-        self.connect("delete-event", self.on_destroy)
 
         self.vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=12, visible=True)
         self.vbox.set_margin_top(18)
@@ -33,10 +30,6 @@ class BaseApplicationWindow(Gtk.ApplicationWindow):
             button.set_tooltip_text(tooltip)
         return button
 
-    def on_destroy(self, _widget=None, _data=None):
-        """Destroy callback"""
-        self.destroy()
-
     def present(self):  # pylint: disable=arguments-differ
         """The base implementation doesn't always work, this one does."""
         self.set_keep_above(True)
