@@ -1,10 +1,11 @@
 """Transform runner parameters to data usable for runtime execution"""
+
 import os
 import shlex
 import stat
 
-from lutris.exceptions import MissingExecutableError
 from lutris.util import cache_single, system
+from lutris.util.graphics.gpu import GPUS
 from lutris.util.linux import LINUX_SYSTEM
 from lutris.util.log import logger
 
@@ -21,9 +22,7 @@ def get_mangohud_conf(system_config):
 def get_launch_parameters(runner, gameplay_info):
     system_config = runner.system_config
     launch_arguments = gameplay_info["command"]
-    env = {
-        "DISABLE_LAYER_AMD_SWITCHABLE_GRAPHICS_1": "1"
-    }
+    env = {}
 
     # Steam compatibility
     if os.environ.get("SteamAppId"):
@@ -34,17 +33,6 @@ def get_launch_parameters(runner, gameplay_info):
     if system_config["locale"] != "":
         env["LC_ALL"] = system_config["locale"]
 
-    # Optimus
-    optimus = system_config.get("optimus")
-    if optimus == "primusrun" and system.can_find_executable("primusrun"):
-        launch_arguments.insert(0, "primusrun")
-    elif optimus == "optirun" and system.can_find_executable("optirun"):
-        launch_arguments.insert(0, "virtualgl")
-        launch_arguments.insert(0, "-b")
-        launch_arguments.insert(0, "optirun")
-    elif optimus == "pvkrun" and system.can_find_executable("pvkrun"):
-        launch_arguments.insert(0, "pvkrun")
-
     # MangoHud
     if runner.name == "steam":
         logger.info(
@@ -57,15 +45,6 @@ def get_launch_parameters(runner, gameplay_info):
             launch_arguments = mango_args + launch_arguments
             env.update(mango_env)
 
-    # Libstrangle
-    fps_limit = system_config.get("fps_limit") or ""
-    if fps_limit:
-        try:
-            strangle_cmd = system.find_executable("strangle")
-            launch_arguments = [strangle_cmd, fps_limit] + launch_arguments
-        except MissingExecutableError:
-            logger.warning("libstrangle is not available on this system, FPS limiter disabled")
-
     prefix_command = system_config.get("prefix_command") or ""
     if prefix_command:
         launch_arguments = shlex.split(os.path.expandvars(prefix_command)) + launch_arguments
@@ -99,8 +78,7 @@ def get_launch_parameters(runner, gameplay_info):
     game_ld_library_path = gameplay_info.get("ld_library_path")
     if game_ld_library_path:
         ld_library_path = env.get("LD_LIBRARY_PATH")
-        env["LD_LIBRARY_PATH"] = os.pathsep.join(filter(None, [
-            game_ld_library_path, ld_library_path]))
+        env["LD_LIBRARY_PATH"] = os.pathsep.join(filter(None, [game_ld_library_path, ld_library_path]))
 
     # Feral gamemode
     gamemode = system_config.get("gamemode") and LINUX_SYSTEM.gamemode_available()
@@ -111,18 +89,24 @@ def get_launch_parameters(runner, gameplay_info):
     has_gamescope = system_config.get("gamescope") and system.can_find_executable("gamescope")
     if has_gamescope:
         launch_arguments = get_gamescope_args(launch_arguments, system_config)
+        if system_config.get("gamescope_hdr"):
+            env["ENABLE_HDR_WSI"] = "1"
 
     return launch_arguments, env
 
 
 def get_gamescope_args(launch_arguments, system_config):
     """Insert gamescope at the start of the launch arguments"""
+    if system_config.get("gamescope_hdr"):
+        launch_arguments.insert(0, "DISABLE_HDR_WSI=1")
+        launch_arguments.insert(0, "DXVK_HDR=1")
+        launch_arguments.insert(0, "ENABLE_GAMESCOPE_WSI=1")
+        launch_arguments.insert(0, "env")
     launch_arguments.insert(0, "--")
     if system_config.get("gamescope_force_grab_cursor"):
         launch_arguments.insert(0, "--force-grab-cursor")
     if system_config.get("gamescope_fsr_sharpness"):
-        gamescope_fsr_sharpness = system_config["gamescope_fsr_sharpness"]
-        launch_arguments.insert(0, gamescope_fsr_sharpness)
+        launch_arguments.insert(0, system_config["gamescope_fsr_sharpness"])
         launch_arguments.insert(0, "--fsr-sharpness")
         launch_arguments[0:0] = _get_gamescope_fsr_option()
     if system_config.get("gamescope_flags"):
@@ -147,6 +131,13 @@ def get_gamescope_args(launch_arguments, system_config):
         launch_arguments.insert(0, "-h")
         launch_arguments.insert(0, game_width)
         launch_arguments.insert(0, "-w")
+    if system_config.get("gpu") and len(GPUS) > 1:
+        gpu = GPUS[system_config["gpu"]]
+        launch_arguments.insert(0, gpu.pci_id)
+        launch_arguments.insert(0, "--prefer-vk-device")
+    if system_config.get("gamescope_hdr"):
+        launch_arguments.insert(0, "--hdr-debug-force-output")
+        launch_arguments.insert(0, "--hdr-enabled")
     launch_arguments.insert(0, "gamescope")
     return launch_arguments
 
@@ -187,7 +178,7 @@ def export_bash_script(runner, gameplay_info, script_path):
     script_content += "\n# Command\n"
     script_content += " ".join([shlex.quote(c) for c in command])
 
-    with open(script_path, "w", encoding='utf-8') as script_file:
+    with open(script_path, "w", encoding="utf-8") as script_file:
         script_file.write(script_content)
 
     os.chmod(script_path, os.stat(script_path).st_mode | stat.S_IEXEC)
