@@ -1,4 +1,5 @@
 """Runner for Linux games"""
+
 # Standard Library
 import os
 import stat
@@ -6,7 +7,7 @@ from gettext import gettext as _
 from typing import Callable
 
 # Lutris Modules
-from lutris.exceptions import GameConfigError, MissingExecutableError, MissingGameExecutableError
+from lutris.exceptions import GameConfigError, MissingGameExecutableError
 from lutris.runners.runner import Runner
 from lutris.util import system
 from lutris.util.strings import split_arguments
@@ -79,10 +80,7 @@ class linux(Runner):
             return exe
         if self.game_path:
             return os.path.join(self.game_path, exe)
-        try:
-            return system.find_executable(exe)
-        except MissingExecutableError:
-            return None
+        return system.find_executable(exe)
 
     def resolve_game_path(self):
         return super().resolve_game_path() or os.path.dirname(self.game_exe or "")
@@ -137,7 +135,7 @@ class linux(Runner):
         working_dir = os.path.expanduser(launch_config.get("working_dir") or self.working_dir)
 
         if "exe" in launch_config:
-            config_exe = os.path.expanduser(launch_config["exe"] or '')
+            config_exe = os.path.expanduser(launch_config["exe"] or "")
             command.append(self.get_relative_exe(config_exe, working_dir))
         elif len(command) == 0:
             raise GameConfigError(_("The runner could not find a command or exe to use for this configuration."))
