@@ -1,24 +1,25 @@
 """Base module for runners"""
+
 import os
 import signal
 from gettext import gettext as _
-from typing import Callable, Dict
+from typing import Any, Callable, Dict, Optional
 
 from lutris import runtime, settings
 from lutris.api import format_runner_version, get_default_runner_version_info
-from lutris.command import MonitoredCommand
 from lutris.config import LutrisConfig
 from lutris.database.games import get_game_by_field
 from lutris.exceptions import MisconfigurationError, MissingExecutableError, UnavailableLibrariesError
+from lutris.monitored_command import MonitoredCommand
 from lutris.runners import RunnerInstallationError
 from lutris.util import flatpak, strings, system
 from lutris.util.extract import ExtractError, extract_archive
+from lutris.util.graphics.gpu import GPUS
 from lutris.util.linux import LINUX_SYSTEM
 from lutris.util.log import logger
 
 
 class Runner:  # pylint: disable=too-many-public-methods
-
     """Generic runner (base class for other runners)."""
 
     multiple_versions = False
@@ -34,7 +35,6 @@ class Runner:  # pylint: disable=too-many-public-methods
     download_url = None
     arch = None  # If the runner is only available for an architecture that isn't x86_64
     flatpak_id = None
-    has_runner_versions = False
 
     def __init__(self, config=None):
         """Initialize runner."""
@@ -177,7 +177,7 @@ class Runner:  # pylint: disable=too-many-public-methods
                 "default": True,
                 "advanced": True,
                 "scope": ["runner"],
-                "help": _("Show this runner in the side panel if it is installed or available through Flatpak.")
+                "help": _("Show this runner in the side panel if it is installed or available through Flatpak."),
             }
         )
         return runner_options
@@ -225,7 +225,7 @@ class Runner:  # pylint: disable=too-many-public-methods
         if sdl_gamecontrollerconfig:
             path = os.path.expanduser(sdl_gamecontrollerconfig)
             if system.path_exists(path):
-                with open(path, "r", encoding='utf-8') as controllerdb_file:
+                with open(path, "r", encoding="utf-8") as controllerdb_file:
                     sdl_gamecontrollerconfig = controllerdb_file.read()
             env["SDL_GAMECONTROLLERCONFIG"] = sdl_gamecontrollerconfig
 
@@ -234,26 +234,22 @@ class Runner:  # pylint: disable=too-many-public-methods
         if sdl_video_fullscreen and sdl_video_fullscreen != "off":
             env["SDL_VIDEO_FULLSCREEN_DISPLAY"] = sdl_video_fullscreen
 
-        # DRI Prime
-        if self.system_config.get("dri_prime"):
-            env["DRI_PRIME"] = "1"
-
-        # Prime vars
-        prime = self.system_config.get("prime")
-        if prime:
-            env["__NV_PRIME_RENDER_OFFLOAD"] = "1"
-            env["__GLX_VENDOR_LIBRARY_NAME"] = "nvidia"
-            env["__VK_LAYER_NV_optimus"] = "NVIDIA_only"
+        if self.system_config.get("gpu") and len(GPUS) > 1:
+            gpu = GPUS[self.system_config["gpu"]]
+            if gpu.driver == "nvidia":
+                env["DRI_PRIME"] = "1"
+                env["__NV_PRIME_RENDER_OFFLOAD"] = "1"
+                env["__GLX_VENDOR_LIBRARY_NAME"] = "nvidia"
+                env["__VK_LAYER_NV_optimus"] = "NVIDIA_only"
+            else:
+                env["DRI_PRIME"] = gpu.pci_id
+            env["VK_ICD_FILENAMES"] = gpu.icd_files  # Deprecated
+            env["VK_DRIVER_FILES"] = gpu.icd_files  # Current form
 
         # Set PulseAudio latency to 60ms
         if self.system_config.get("pulse_latency"):
             env["PULSE_LATENCY_MSEC"] = "60"
 
-        # Vulkan ICD files
-        vk_icd = self.system_config.get("vk_icd")
-        if vk_icd:
-            env["VK_ICD_FILENAMES"] = vk_icd
-
         runtime_ld_library_path = None
 
         if not disable_runtime and self.use_runtime():
@@ -262,8 +258,7 @@ class Runner:  # pylint: disable=too-many-public-methods
 
         if runtime_ld_library_path:
             ld_library_path = env.get("LD_LIBRARY_PATH")
-            env["LD_LIBRARY_PATH"] = os.pathsep.join(filter(None, [
-                runtime_ld_library_path, ld_library_path]))
+            env["LD_LIBRARY_PATH"] = os.pathsep.join(filter(None, [runtime_ld_library_path, ld_library_path]))
 
         # Apply user overrides at the end
         env.update(self.system_config.get("env") or {})
@@ -426,8 +421,7 @@ class Runner:  # pylint: disable=too-many-public-methods
         """
 
         if ui_delegate.show_install_yesno_inquiry(
-            question=_("The required runner is not installed.\n"
-                       "Do you wish to install it now?"),
+            question=_("The required runner is not installed.\n" "Do you wish to install it now?"),
             title=_("Required runner unavailable"),
         ):
             if hasattr(self, "get_version"):
@@ -456,8 +450,13 @@ class Runner:  # pylint: disable=too-many-public-methods
         script settings, to determine more precisely what must be installed."""
         return self.is_installed()
 
-    def get_installer_runner_version(self, installer, use_runner_config: bool = True) -> str:
-        raise RuntimeError("The '%s' runner does not support versions" % self.name)
+    def get_installer_runner_version(self, installer, use_runner_config: bool = True) -> Optional[str]:
+        return None
+
+    def adjust_installer_runner_config(self, installer_runner_config: Dict[str, Any]) -> None:
+        """This is called during installation to let to run fix up in the runner's section of
+        the configuration before it is saved. This method should modify the dict given."""
+        pass
 
     def get_runner_version(self, version: str = None) -> Dict[str, str]:
         """Get the appropriate version for a runner, as with get_default_runner_version(),
@@ -482,9 +481,7 @@ class Runner:  # pylint: disable=too-many-public-methods
 
         if "wine" in self.name:
             opts["merge_single"] = True
-            opts["dest"] = os.path.join(
-                self.directory, format_runner_version(runner_version_info)
-            )
+            opts["dest"] = os.path.join(self.directory, format_runner_version(runner_version_info))
 
         if self.name == "libretro" and version:
             opts["merge_single"] = False
@@ -516,6 +513,7 @@ class Runner:  # pylint: disable=too-many-public-methods
         if self.name == "wine":
             logger.debug("Clearing wine version cache")
             from lutris.util.wine.wine import get_installed_wine_versions
+
             get_installed_wine_versions.cache_clear()
 
         if self.runner_executable:
@@ -541,7 +539,7 @@ class Runner:  # pylint: disable=too-many-public-methods
 
     def find_option(self, options_group, option_name):
         """Retrieve an option dict if it exists in the group"""
-        if options_group not in ['game_options', 'runner_options']:
+        if options_group not in ["game_options", "runner_options"]:
             return None
         output = None
         for item in getattr(self, options_group):
