@@ -6,6 +6,7 @@ from gettext import gettext as _
 
 # Lutris Modules
 from lutris import settings
+from lutris.exceptions import MissingGameExecutableError
 from lutris.runners.runner import Runner
 from lutris.util import system
 from lutris.util.log import logger
@@ -19,6 +20,7 @@ class snes9x(Runner):
     platforms = [_("Nintendo SNES")]
     runnable_alone = True
     runner_executable = "snes9x/bin/snes9x-gtk"
+    flatpak_id = "com.snes9x.Snes9x"
     game_options = [
         {
             "option": "main_file",
@@ -30,13 +32,7 @@ class snes9x(Runner):
     ]
 
     runner_options = [
-        {
-            "option": "fullscreen",
-            "type": "bool",
-            "section": _("Graphics"),
-            "label": _("Fullscreen"),
-            "default": "1"
-        },
+        {"option": "fullscreen", "type": "bool", "section": _("Graphics"), "label": _("Fullscreen"), "default": "1"},
         {
             "option": "maintain_aspect_ratio",
             "type": "bool",
@@ -64,7 +60,7 @@ class snes9x(Runner):
     def set_option(self, option, value):
         config_file = os.path.expanduser("~/.snes9x/snes9x.xml")
         if not system.path_exists(config_file):
-            with subprocess.Popen([self.get_executable(), "-help"]) as snes9x_process:
+            with subprocess.Popen(self.get_command() + ["-help"]) as snes9x_process:
                 snes9x_process.communicate()
         if not system.path_exists(config_file):
             logger.error("Snes9x config file creation failed")
@@ -82,5 +78,5 @@ class snes9x(Runner):
 
         rom = self.game_config.get("main_file") or ""
         if not system.path_exists(rom):
-            return {"error": "FILE_NOT_FOUND", "file": rom}
-        return {"command": [self.get_executable(), rom]}
+            raise MissingGameExecutableError(filename=rom)
+        return {"command": self.get_command() + [rom]}
