@@ -1,4 +1,5 @@
 """Epic Games Store service"""
+
 import json
 import os
 from gettext import gettext as _
@@ -33,8 +34,7 @@ BOX_ART_SIZE = (200, 267)
 class DieselGameMedia(ServiceMedia):
     service = "egs"
     remote_size = (200, 267)
-    file_pattern = "%s.jpg"
-    file_format = "jpeg"
+    file_patterns = ["%s.jpg"]
     min_logo_x = 300
     min_logo_y = 150
 
@@ -52,12 +52,12 @@ class DieselGameMedia(ServiceMedia):
             if logo_width > self.min_logo_x:
                 logo_image = logo_image.resize(
                     (self.min_logo_x, int(logo_height * (self.min_logo_x / logo_width))),
-                    resample=Image.Resampling.BICUBIC
+                    resample=Image.Resampling.BICUBIC,
                 )
             elif logo_height > self.min_logo_y:
                 logo_image = logo_image.resize(
                     (int(logo_width * (self.min_logo_y / logo_height)), self.min_logo_y),
-                    resample=Image.Resampling.BICUBIC
+                    resample=Image.Resampling.BICUBIC,
                 )
             thumb_image = paste_overlay(thumb_image, logo_image)
         thumb_path = os.path.join(self.dest_path, filename)
@@ -67,14 +67,12 @@ class DieselGameMedia(ServiceMedia):
     def get_media_url(self, details):
         for image in details.get("keyImages", []):
             if image["type"] == self.api_field:
-                return image["url"] + "?w=%s&resize=1&h=%s" % (
-                    self.remote_size[0],
-                    self.remote_size[1]
-                )
+                return image["url"] + "?w=%s&resize=1&h=%s" % (self.remote_size[0], self.remote_size[1])
 
 
 class DieselGameBoxTall(DieselGameMedia):
     """EGS tall game box"""
+
     size = (200, 267)
     remote_size = size
     min_logo_x = 100
@@ -94,6 +92,7 @@ class DieselGameBoxSmall(DieselGameBoxTall):
 
 class DieselGameBox(DieselGameBoxTall):
     """EGS game box"""
+
     size = (316, 178)
     remote_size = size
     min_logo_x = 300
@@ -109,10 +108,10 @@ class DieselGameBannerSmall(DieselGameBox):
 
 class DieselGameBoxLogo(DieselGameMedia):
     """EGS game box"""
+
     size = (200, 100)
     remote_size = size
-    file_pattern = "%s.png"
-    file_format = "png"
+    file_patterns = ["%s.png"]
     visible = False
     dest_path = os.path.join(settings.CACHE_DIR, "egs/game_logo")
     api_field = "DieselGameBoxLogo"
@@ -120,6 +119,7 @@ class DieselGameBoxLogo(DieselGameMedia):
 
 class EGSGame(ServiceGame):
     """Service game for Epic Games Store"""
+
     service = "egs"
 
     @classmethod
@@ -158,46 +158,37 @@ class EpicGamesStoreService(OnlineService):
     cookies_path = os.path.join(settings.CACHE_DIR, ".egs.auth")
     token_path = os.path.join(settings.CACHE_DIR, ".egs.token")
     cache_path = os.path.join(settings.CACHE_DIR, "egs-library.json")
-    login_url = ("https://www.epicgames.com/id/login?redirectUrl="
-                 "https%3A//www.epicgames.com/id/api/redirect%3F"
-                 "clientId%3D34a02cf8f4414e29b15921876da36f9a%26responseType%3Dcode")
+    login_url = (
+        "https://www.epicgames.com/id/login?redirectUrl="
+        "https%3A//www.epicgames.com/id/api/redirect%3F"
+        "clientId%3D34a02cf8f4414e29b15921876da36f9a%26responseType%3Dcode"
+    )
     redirect_uri = "https://www.epicgames.com/id/api/redirect"
-    oauth_url = 'https://account-public-service-prod03.ol.epicgames.com'
-    catalog_url = 'https://catalog-public-service-prod06.ol.epicgames.com'
-    library_url = 'https://library-service.live.use1a.on.epicgames.com'
+    oauth_url = "https://account-public-service-prod03.ol.epicgames.com"
+    catalog_url = "https://catalog-public-service-prod06.ol.epicgames.com"
+    library_url = "https://library-service.live.use1a.on.epicgames.com"
 
     user_agent = (
-        'Mozilla/5.0 (Windows NT 10.0; Win64; x64) '
-        'AppleWebKit/537.36 (KHTML, like Gecko) '
-        'EpicGamesLauncher/11.0.1-14907503+++Portal+Release-Live '
-        'UnrealEngine/4.23.0-14907503+++Portal+Release-Live '
-        'Chrome/84.0.4147.38 Safari/537.36'
+        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) "
+        "AppleWebKit/537.36 (KHTML, like Gecko) "
+        "EpicGamesLauncher/11.0.1-14907503+++Portal+Release-Live "
+        "UnrealEngine/4.23.0-14907503+++Portal+Release-Live "
+        "Chrome/84.0.4147.38 Safari/537.36"
     )
 
     def __init__(self):
         super().__init__()
         self.session = requests.session()
-        self.session.headers['User-Agent'] = self.user_agent
+        self.session.headers["User-Agent"] = self.user_agent
         if os.path.exists(self.token_path):
-            with open(self.token_path, encoding='utf-8') as token_file:
+            with open(self.token_path, encoding="utf-8") as token_file:
                 self.session_data = json.loads(token_file.read())
         else:
             self.session_data = {}
 
     @property
     def http_basic_auth(self):
-        return requests.auth.HTTPBasicAuth(
-            '34a02cf8f4414e29b15921876da36f9a',
-            'daafbccc737745039dffe53d94fc76cf'
-        )
-
-    def run(self):
-        egs = get_game_by_field(self.client_installer, "slug")
-        egs_game = Game(egs["id"])
-        egs_game.emit("game-launch")
-
-    def is_launchable(self):
-        return get_game_by_field(self.client_installer, "slug")
+        return requests.auth.HTTPBasicAuth("34a02cf8f4414e29b15921876da36f9a", "daafbccc737745039dffe53d94fc76cf")
 
     def is_connected(self):
         return self.is_authenticated()
@@ -215,48 +206,40 @@ class EpicGamesStoreService(OnlineService):
         self.emit("service-login")
 
     def resume_session(self):
-        self.session.headers['Authorization'] = 'bearer %s' % self.session_data["access_token"]
-        response = self.session.get('%s/account/api/oauth/verify' % self.oauth_url)
+        self.session.headers["Authorization"] = "bearer %s" % self.session_data["access_token"]
+        response = self.session.get("%s/account/api/oauth/verify" % self.oauth_url)
         if response.status_code >= 500:
             response.raise_for_status()
 
         response_content = response.json()
-        if 'errorMessage' in response_content:
+        if "errorMessage" in response_content:
             raise RuntimeError(response_content)
         return response_content
 
     def start_session(self, exchange_code=None, authorization_code=None):
         if exchange_code:
-            params = {
-                'grant_type': 'exchange_code',
-                'exchange_code': exchange_code,
-                'token_type': 'eg1'
-            }
+            params = {"grant_type": "exchange_code", "exchange_code": exchange_code, "token_type": "eg1"}
         elif authorization_code:
-            params = {
-                'grant_type': 'authorization_code',
-                'code': authorization_code,
-                'token_type': 'eg1'
-            }
+            params = {"grant_type": "authorization_code", "code": authorization_code, "token_type": "eg1"}
         else:
             params = {
-                'grant_type': 'refresh_token',
-                'refresh_token': self.session_data["refresh_token"],
-                'token_type': 'eg1'
+                "grant_type": "refresh_token",
+                "refresh_token": self.session_data["refresh_token"],
+                "token_type": "eg1",
             }
 
         response = self.session.post(
-            'https://account-public-service-prod03.ol.epicgames.com/account/api/oauth/token',
+            "https://account-public-service-prod03.ol.epicgames.com/account/api/oauth/token",
             data=params,
-            auth=self.http_basic_auth
+            auth=self.http_basic_auth,
         )
         if response.status_code >= 500:
             response.raise_for_status()
 
         response_content = response.json()
-        if 'error' in response_content:
+        if "error" in response_content:
             raise RuntimeError(response_content)
-        with open(self.token_path, "w", encoding='utf-8') as auth_file:
+        with open(self.token_path, "w", encoding="utf-8") as auth_file:
             auth_file.write(json.dumps(response_content, indent=2))
         self.session_data = response_content
 
@@ -264,14 +247,14 @@ class EpicGamesStoreService(OnlineService):
         namespace = asset["namespace"]
         catalog_item_id = asset["catalogItemId"]
         response = self.session.get(
-            '%s/catalog/api/shared/namespace/%s/bulk/items' % (self.catalog_url, namespace),
+            "%s/catalog/api/shared/namespace/%s/bulk/items" % (self.catalog_url, namespace),
             params={
                 "id": catalog_item_id,
                 "includeDLCDetails": True,
                 "includeMainGameDetails": True,
                 "country": "US",
-                "locale": "en"
-            }
+                "locale": "en",
+            },
         )
         response.raise_for_status()
         # Merge the details with the initial asset to keep 'appName'
@@ -281,23 +264,20 @@ class EpicGamesStoreService(OnlineService):
     def get_library(self):
         self.resume_session()
         response = self.session.get(
-            '%s/library/api/public/items' % self.library_url,
-            params={'includeMetadata': 'true'}
+            "%s/library/api/public/items" % self.library_url, params={"includeMetadata": "true"}
         )
         response.raise_for_status()
         resData = response.json()
-        records = resData['records']
-        cursor = resData['responseMetadata'].get('nextCursor', None)
+        records = resData["records"]
+        cursor = resData["responseMetadata"].get("nextCursor", None)
         while cursor:
             response = self.session.get(
-                '%s/library/api/public/items' % self.library_url,
-                params={'includeMetadata': 'true',
-                        'cursor': cursor}
+                "%s/library/api/public/items" % self.library_url, params={"includeMetadata": "true", "cursor": cursor}
             )
             response.raise_for_status()
             resData = response.json()
-            records.extend(resData['records'])
-            cursor = resData['responseMetadata'].get('nextCursor', None)
+            records.extend(resData["records"])
+            cursor = resData["responseMetadata"].get("nextCursor", None)
 
         games = []
         for record in records:
@@ -389,19 +369,21 @@ class EpicGamesStoreService(OnlineService):
                     "args": get_launch_arguments(db_game["appid"]),
                 },
                 "installer": [
-                    {"task": {
-                        "name": "wineexec",
-                        "executable": egs_exe,
-                        "args": get_launch_arguments(db_game["appid"], "install"),
-                        "prefix": egs_game.config.game_config["prefix"],
-                        "description": (
-                            "The Epic Game Store will now open. Please launch "
-                            "the installation of %s then close the EGS client "
-                            "once the game has been downloaded." % db_game["name"]
-                        )
-                    }}
-                ]
-            }
+                    {
+                        "task": {
+                            "name": "wineexec",
+                            "executable": egs_exe,
+                            "args": get_launch_arguments(db_game["appid"], "install"),
+                            "prefix": egs_game.config.game_config["prefix"],
+                            "description": (
+                                "The Epic Game Store will now open. Please launch "
+                                "the installation of %s then close the EGS client "
+                                "once the game has been downloaded." % db_game["name"]
+                            ),
+                        }
+                    }
+                ],
+            },
         }
 
     def get_installed_runner_name(self, db_game):
@@ -415,15 +397,9 @@ class EpicGamesStoreService(OnlineService):
             application.show_lutris_installer_window(game_slug=self.client_installer)
         else:
             application.show_installer_window(
-                [self.generate_installer(db_game, egs_game)],
-                service=self,
-                appid=db_game["appid"]
+                [self.generate_installer(db_game, egs_game)], service=self, appid=db_game["appid"]
             )
 
 
 def get_launch_arguments(app_name, action="launch"):
-    return (
-        "-opengl"
-        " -SkipBuildPatchPrereq"
-        " -com.epicgames.launcher://apps/%s?action=%s"
-    ) % (app_name, action)
+    return ("-opengl" " -SkipBuildPatchPrereq" " -com.epicgames.launcher://apps/%s?action=%s") % (app_name, action)
