@@ -2,14 +2,26 @@ import json
 import os
 import random
 import time
+from typing import List
 
-from lutris import settings
 from lutris.database.services import ServiceGameCollection
 from lutris.util import system
 from lutris.util.http import HTTPError, download_file
 from lutris.util.log import logger
+from lutris.util.portals import TrashPortal
 
-PGA_DB = settings.PGA_DB
+
+def resolve_media_path(possible_paths: List[str]) -> str:
+    """Selects the best path from a list of paths to media. This will take the first
+    one that exists and has contents, or the just first one if none are usable."""
+    if len(possible_paths) > 1:
+        for path in possible_paths:
+            if system.path_exists(path, exclude_empty=True) and os.path.isfile(path):
+                return path
+    elif not possible_paths:
+        raise ValueError("resolve_media_path() requires at least one path.")
+
+    return possible_paths[0]
 
 
 class ServiceMedia:
@@ -19,10 +31,8 @@ class ServiceMedia:
     size = NotImplemented
     source = "remote"  # set to local if the files don't need to be downloaded
     visible = True  # This media should be displayed as an option in the UI
-    small_size = None
-    dest_path = None
-    file_pattern = NotImplemented
-    file_format = NotImplemented
+    dest_path = NotImplemented
+    file_patterns = NotImplemented
     api_field = NotImplemented
     url_pattern = "%s"
 
@@ -31,15 +41,26 @@ class ServiceMedia:
             os.makedirs(self.dest_path)
 
     def get_filename(self, slug):
-        return self.file_pattern % slug
+        return self.file_patterns[0] % slug
 
-    def get_media_path(self, slug):
-        """Return the absolute path of a local media file"""
-        return os.path.join(self.dest_path, self.get_filename(slug))
+    def get_possible_media_paths(self, slug: str) -> List[str]:
+        """Returns a list of each path where the media might be found. At most one of these should
+        be found, but they are in a priority order - the first is in the preferred format."""
+        return [os.path.join(self.dest_path, pattern % slug) for pattern in self.file_patterns]
 
-    def exists(self, slug):
-        """Whether the icon for the specified slug exists locally"""
-        return system.path_exists(self.get_media_path(slug))
+    def trash_media(
+        self,
+        slug: str,
+        completion_function: TrashPortal.CompletionFunction = None,
+        error_function: TrashPortal.ErrorFunction = None,
+    ) -> None:
+        """Sends each media file for a game to the trash, and invokes callsbacks when this
+        has been completed or has failed."""
+        paths = [path for path in self.get_possible_media_paths(slug) if os.path.exists(path)]
+        if paths:
+            TrashPortal(paths, completion_function=completion_function, error_function=error_function)
+        elif completion_function:
+            completion_function()
 
     def get_media_url(self, details):
         if self.api_field not in details:
