@@ -1,4 +1,5 @@
 import os
+import threading
 import time
 
 import requests
@@ -15,7 +16,6 @@ get_time = time.monotonic
 
 
 class Downloader:
-
     """Non-blocking downloader.
 
     Do start() then check_progress() at regular intervals.
@@ -23,41 +23,36 @@ class Downloader:
     Stop with cancel().
     """
 
-    (
-        INIT,
-        DOWNLOADING,
-        CANCELLED,
-        ERROR,
-        COMPLETED
-    ) = list(range(5))
+    (INIT, DOWNLOADING, CANCELLED, ERROR, COMPLETED) = list(range(5))
 
-    def __init__(self, url, dest, overwrite=False, referer=None, callback=None):
-        self.url = url
-        self.dest = dest
-        self.overwrite = overwrite
+    def __init__(self, url: str, dest: str, overwrite: bool = False, referer=None, cookies=None) -> None:
+        self.url: str = url
+        self.dest: str = dest
+        self.cookies = cookies
+        self.overwrite: bool = overwrite
         self.referer = referer
         self.stop_request = None
         self.thread = None
-        self.callback = callback
 
         # Read these after a check_progress()
         self.state = self.INIT
         self.error = None
-        self.downloaded_size = 0  # Bytes
-        self.full_size = 0  # Bytes
-        self.progress_fraction = 0
-        self.progress_percentage = 0
+        self.downloaded_size: int = 0  # Bytes
+        self.full_size: int = 0  # Bytes
+        self.progress_fraction: float = 0
+        self.progress_percentage: float = 0
         self.speed = 0
         self.average_speed = 0
-        self.time_left = "00:00:00"  # Based on average speed
-        self.last_size = 0
-        self.last_check_time = 0
+        self.time_left: str = "00:00:00"  # Based on average speed
+        self.last_size: int = 0
+        self.last_check_time: float = 0.0
         self.last_speeds = []
         self.speed_check_time = 0
         self.time_left_check_time = 0
         self.file_pointer = None
+        self.progress_event = threading.Event()
 
-    def __str__(self):
+    def __repr__(self):
         return "downloader for %s" % self.url
 
     def start(self):
@@ -68,7 +63,7 @@ class Downloader:
         if self.overwrite and os.path.isfile(self.dest):
             os.remove(self.dest)
         self.file_pointer = open(self.dest, "wb")  # pylint: disable=consider-using-with
-        self.thread = jobs.AsyncCall(self.async_download, self.download_cb)
+        self.thread = jobs.AsyncCall(self.async_download, None)
         self.stop_request = self.thread.stop_request
 
     def reset(self):
@@ -83,20 +78,41 @@ class Downloader:
         self.average_speed = 0
         self.time_left = "00:00:00"  # Based on average speed
         self.last_size = 0
-        self.last_check_time = 0
+        self.last_check_time = 0.0
         self.last_speeds = []
         self.speed_check_time = 0
         self.time_left_check_time = 0
         self.file_pointer = None
 
-    def check_progress(self):
+    def check_progress(self, blocking=False):
         """Append last downloaded chunk to dest file and store stats.
 
+        blocking: if true and still downloading, block until some progress is made.
         :return: progress (between 0.0 and 1.0)"""
+        if blocking and self.state in [self.INIT, self.DOWNLOADING] and self.progress_fraction < 1.0:
+            self.progress_event.wait()
+            self.progress_event.clear()
+
         if self.state not in [self.CANCELLED, self.ERROR]:
             self.get_stats()
         return self.progress_fraction
 
+    def join(self, progress_callback=None):
+        """Blocks waiting for the download to complete.
+
+        'progress_callback' is invoked repeatedly as the download
+        proceeds, if given, and is passed the downloader itself.
+
+        Returns True on success, False if cancelled."""
+        while self.state == self.DOWNLOADING:
+            self.check_progress(blocking=True)
+            if progress_callback:
+                progress_callback(self)
+
+        if self.error:
+            raise self.error
+        return self.state == self.COMPLETED
+
     def cancel(self):
         """Request download stop and remove destination file."""
         logger.debug("❌ %s", self.url)
@@ -109,16 +125,41 @@ class Downloader:
         if os.path.isfile(self.dest):
             os.remove(self.dest)
 
-    def download_cb(self, _result, error):
-        if error:
-            logger.error("Download failed: %s", error)
+    def async_download(self):
+        try:
+            headers = requests.utils.default_headers()
+            headers["User-Agent"] = "Lutris/%s" % __version__
+            if self.referer:
+                headers["Referer"] = self.referer
+            response = requests.get(self.url, headers=headers, stream=True, timeout=30, cookies=self.cookies)
+            if response.status_code != 200:
+                logger.info("%s returned a %s error", self.url, response.status_code)
+            response.raise_for_status()
+            self.full_size = int(response.headers.get("Content-Length", "").strip() or 0)
+            self.progress_event.set()
+            for chunk in response.iter_content(chunk_size=8192):
+                if not self.file_pointer:
+                    break
+                if chunk:
+                    self.downloaded_size += len(chunk)
+                    self.file_pointer.write(chunk)
+                self.progress_event.set()
+            self.on_download_completed()
+        except Exception as ex:
+            logger.exception("Download failed: %s", ex)
+            self.on_download_failed(ex)
+
+    def on_download_failed(self, error: Exception):
+        # Cancelling closes the file, which can result in an
+        # error. If so, we just remain cancelled.
+        if self.state != self.CANCELLED:
             self.state = self.ERROR
             self.error = error
-            if self.file_pointer:
-                self.file_pointer.close()
-                self.file_pointer = None
-            return
+        if self.file_pointer:
+            self.file_pointer.close()
+            self.file_pointer = None
 
+    def on_download_completed(self):
         if self.state == self.CANCELLED:
             return
 
@@ -132,25 +173,6 @@ class Downloader:
         self.state = self.COMPLETED
         self.file_pointer.close()
         self.file_pointer = None
-        if self.callback:
-            self.callback()
-
-    def async_download(self, stop_request=None):
-        headers = requests.utils.default_headers()
-        headers["User-Agent"] = "Lutris/%s" % __version__
-        if self.referer:
-            headers["Referer"] = self.referer
-        response = requests.get(self.url, headers=headers, stream=True)
-        if response.status_code != 200:
-            logger.info("%s returned a %s error", self.url, response.status_code)
-        response.raise_for_status()
-        self.full_size = int(response.headers.get("Content-Length", "").strip() or 0)
-        for chunk in response.iter_content(chunk_size=1024):
-            if not self.file_pointer:
-                break
-            if chunk:
-                self.downloaded_size += len(chunk)
-                self.file_pointer.write(chunk)
 
     def get_stats(self):
         """Calculate and store download stats."""
@@ -188,7 +210,7 @@ class Downloader:
         self.speed_check_time = get_time()
         return speed, average_speed
 
-    def get_average_time_left(self):
+    def get_average_time_left(self) -> str:
         """Return average download time left as string."""
         if not self.full_size:
             return "???"
