@@ -1,5 +1,6 @@
-import os
 import configparser
+import os
+
 from lutris.util.log import logger
 
 
@@ -15,13 +16,9 @@ class SettingsIO:
             except configparser.ParsingError as ex:
                 logger.error("Failed to readconfig file %s: %s", self.config_file, ex)
             except UnicodeDecodeError as ex:
-                logger.error(
-                    "Some invalid characters are preventing "
-                    "the setting file from loading properly: %s",
-                    ex
-                )
+                logger.error("Some invalid characters are preventing the setting file from loading properly: %s", ex)
 
-    def read_setting(self, key, section="lutris", default=""):
+    def read_setting(self, key, default="", section="lutris"):
         """Read a setting from the config file
 
         Params:
@@ -34,10 +31,19 @@ class SettingsIO:
         except (configparser.NoOptionError, configparser.NoSectionError):
             return default
 
+    def read_bool_setting(self, key: str, default: bool = False, section="lutris") -> bool:
+        text = self.read_setting(key, "", section=section).casefold()
+        if text == "true":
+            return True
+        if text == "false":
+            return False
+
+        return default
+
     def write_setting(self, key, value, section="lutris"):
         if not self.config.has_section(section):
             self.config.add_section(section)
         self.config.set(section, key, str(value))
 
-        with open(self.config_file, "w") as config_file:
+        with open(self.config_file, "w", encoding="utf-8") as config_file:
             self.config.write(config_file)
